# Trainable Segmentation
Segmentation Tools that apply scikit-learn machine learning and various filters to build image feature sets and classify image pixels.

# Contact information:

Heather S. Deter, PhD
Postdoctoral Research Assistant
University of Illinois Urbana Champaign
Email: hdeter2013@gmail.com

# Acknowldegments

H.S.D. was supported by an appointment to the Intelligence Community Postdoctoral Research Fellowship Program at the University of Illinois Urbana-Champaign, administered by Oak Ridge Institute for Science and Education through an interagency agreement between the U.S. Department of Energy and the Office of the Director of National Intelligence.

